# Single-cell recordings from three cortical parietal areas during an instructed-delay reaching task
## Summary
We publish six electrophysiological datasets obtained from three regions (V6A, PEc, PE) within the superior parietal lobule (SPL) of two Macaca fascicularis monkeys (MonkeyS and MonkeyF). The datasets were collected during an instructed delayed foveated reaching task conducted in the absence of light. The task involved reaching towards nine targets positioned at varying depths and directions relative to the monkeys' point of view. We have recorded neural activity from 285, 231, and 166 individual neurons in V6A, PEc, and PE, respectively. Additionally, the timing of the main behavioral events for each trial is included. The data is stored in .h5 files, which offer a convenient hierarchical structure and the ability to attach various types of information to each hierarchical level. To help you get started, we also provide example code in MATLAB and Python for understanding the data structure.

## Repository structure
##### Directory data
Contains six HDF5 files, each corresponding to a specific animal and area. The naming convention for these files is as follows:

1. *MonkeyF_V6A_reach9pos.h5*
2. *MonkeyF_PEc_reach9pos.h5*
3. *MonkeyF_PE_reach9pos.h5*
4. *MonkeyS_V6A_reach9pos.h5*
5. *MonkeyS_PEc_reach9pos.h5*
6. *MonkeyS_PE_reach9pos.h5*

Each HDF5 file has a hierarchical structure consisting of directories, folders, and subfolders. At the lowest level of the hierarchy, we have the actual datasets. The hierarchical organization of the six datasets is as follows:

* Level 0: /DATA
* Level 1: /DATA/unit
* Level 2: /DATA/unit/cond
* Level 3: /DATA/unit/cond/trial
* Level 4: /DATA/unit/cond/trial/spike_trains
* Level 4: /DATA/unit/cond/trial/marker_events

At Level 1, there is a group for each recorded unit (Unit_01, Unit_02, etc.). Similarly, at Level 2, there is a group for each condition (target) used in the task (Cond_01, Cond_02, etc.). At Level 3, there is a group for each recorded trial (Trial_01, Trial_02, etc.). It's important to note that the number of conditions is fixed for all datasets (nine targets), while the number of trials can vary for each unit, depending on the recorded data.

The final level, Level 4, contains the actual data, which includes the timing (in milliseconds) of each spike (spike_trains) or behavioral event (marker_events) relative to the alignment marker.

For example, /DATA/unit_05/cond_03/trial_07/spike_trains refers to the spiking activity recorded during the seventh trial of the third condition for the fifth unit in the dataset of interest.

Metadata has been added to groups and datasets in the form of 'attributes'. Here is a list of the 16 attributes along with a brief description:

* *Animal* (DATA): The name of the animal ['MonkeyS', 'MonkeyF'].
* *Area* (DATA): The targeted area ['V6A', 'PEc', 'PE'].
* *Total neurons* (DATA): The total number of neurons in a specific dataset.
* *Total conditions* (DATA): The total number of conditions.
* *Total marker events* (DATA): The total number of marker events.
* *Electrode id* (unit): A letter ['A', 'B', 'C', 'D', 'E', 'F'] indicating the recording electrode.
* *Cito* (unit): For V6A, it could be 'V6Ad' if the neuron is recorded from the dorsal part of V6A or 'V6Av' if recorded from the ventral part of V6A45. For other areas, it is the same as the Area attribute.
* *Hemisphere* (unit): Identifier of the hemisphere from which the neuron was recorded, 'L' for left and 'R' for right.
* *Target label* (cond): Labels of the targets ['near left', 'near central', 'near right', 'intermediate left', 'intermediate central', 'intermediate right', 'far left', 'far central', 'far right']. See fig.2.
* *Laterality* (cond): The angle between the frontal (left-right) axis and the projections of the vector connecting the  initial position (home button) and the target on the horizontal plane.
* *Elevation* (cond): The angle between the horizontal plane and the vector connecting the initial position (home button) and the target.
* *Distance* (cond): The distance from the home button to the target.
* *3D cartesian coordinates* (cond): Cartesian coordinates relative to the reference frame centered on the home button. the X-axis corresponds to the frontal axis (positive rightwards), the Y-axis corresponds to the sagittal axis (positive frontwards), and the Z-axis corresponds to the vertical axis (positive upwards).
* *Duration* (trial): The duration in milliseconds of the trial.
* *Number of spikes* (spike_trains): The total number of action potentials recorded.
* *Marker labels* (marker_events): Labels of the marker events ['Start', 'Green on', 'Fix on', 'Green to red', 'Move out on', 'Move out off', 'Red off', 'Move in on', 'Move in off', 'End'].

These attributes provide additional information about the animals, areas, recording details, target properties, trial characteristics, and marker events associated with the datasets.

##### Directory code
In the directory */code* there are two subfolder, */code/matlab* and */code/python* each of them containing the matlab and python example script of two fucntion:
1. *H5_raster.m* or *H5_raster.py* generates a raster plot by plotting the neural and behavioral (event markers) data stored in a .h5 file. The plot displays the activity of a neuron over time, aligning it with specific events or conditions. To customize the plot, the user can modify the 'str' variable at the beginning of the script.
2.  *H5_ISI.m* or *H5_ISI.py* computes the Inter Spike Intervals (ISIs) and creates a histogram to visualize the results. Additionally, it calculates the proportion of ISIs that exceed a chosen threshold (usually set at 1ms) and displays this information in the histogram. To tailor the analysis, the user can modify the 'str' variable at the beginning of the script.

## Related Publications
* Diomedi, S., Vaccari, F. E., Filippini, M., Fattori, P., Galletti, C. (2020). Mixed Selectivity in Macaque Medial Parietal Cortex during Eye-Hand Reaching. IScience, 23(10), 101616. https://doi.org/10.1016/j.isci.2020.101616

* Diomedi, S., Vaccari, F. E., Galletti, C., Hadjidimitrakis, K., Fattori, P. (2021). Motor-like neural dynamics in two parietal areas during arm reaching. Progress in Neurobiology, 205, 102116. https://doi.org/10.1016/j.pneurobio.2021.102116

* De Vitis, M., Tabanelli, M., Breveglieri, R., Filippini, M., Galletti, C., Fattori, P. (2022). The Superior Parietal Lobule of Macaque Monkey: Relative Influence of Gaze and Static Arm Position during Reaching. Eneuro, 9(1), ENEURO.0362-21.2021. https://doi.org/10.1523/ENEURO.0362-21.2021

* Filippini, M., Borra, D., Ursino, M., Magosso, E., Fattori, P. (2022). Decoding sensorimotor information from superior parietal lobule of macaque via Convolutional Neural Networks. Neural Networks, 151, 276–294. https://doi.org/10.1016/j.neunet.2022.03.044

* Hadjidimitrakis, K., De Vitis, M., Ghodrati, M., Filippini, M., Fattori, P. (2022). Anterior-posterior gradient in the integrated processing of forelimb movement direction and distance in macaque parietal cortex. Cell Reports, 41(6), 111608. https://doi.org/10.1016/j.celrep.2022.111608


## Licensing
The six dataset in the directories data by University of Bologna, Bologna, Italy, is licensed under a Creative Commons Attribution 4.0 International License.

All code in the directories /code/matlab, /code/matlab/supportFunctions, /code/python, /code/python/supportFunctions are each published under the BSD 3 clause licenses.

Please see the LICENSE.txt or LICENSE files in individual subdirectories for detailed respective licenses of code and data.
