import numpy as np
import matplotlib.pyplot as plt
from supportFunctions import get_all_data
import tkinter as tk
from tkinter import filedialog
import os


current_dir = os.getcwd()

# Path to open the file dialog window in the data branch
path_folder_data = os.path.abspath(os.path.join(current_dir, "..", ".."))
path_folder_data = os.path.join(path_folder_data, "data")

# Select H5 dataset file
root = tk.Tk()
root.withdraw()
filename = filedialog.askopenfilename(initialdir=path_folder_data)

str = '/DATA/unit_01'  # it can be 'unit_XX', 'unit_XX/condition_YY' or 'unit_XX/condition_YY/trial_ZZ'
threshold = 1  # Soglia per le violazioni in ms
spikes, markers, all_strings = get_all_data.get_all_data_from_level_h5(filename, str)


ISIs = []

# Iterate over each array of spike data
for spike_data in spikes:
    # Calculate the differences for each spike_data array
    spike_data=np.array(spike_data)
    diff_data = np.diff(spike_data.flatten())
    # Append the differences to the list
    ISIs.append(diff_data)

# Concatenate all the differences into a single array
ISIs = np.concatenate(ISIs)

# Calculate the violations
violations = (ISIs < threshold).sum() / ISIs.size * 100


# Creazione dell'istogramma
fig, ax = plt.subplots()
time = np.arange(0, 100.5, 0.5)
ax.hist(ISIs, bins=time)
ax.axvline(threshold, linestyle='--')
xLimits = ax.get_xlim()
yLimits = ax.get_ylim()
ax.text(xLimits[1] / 4, yLimits[1] * 2 / 3, f'Violations (ISI below {threshold}ms threshold) = {violations:.2f}%', fontsize=12)
ax.set_xlabel('Durata ISI (ms)')
ax.set_ylabel('Numero di eventi')
ax.set_title('ISI')
plt.show()